@@ -98,6 +98,8 @@ def main(defaults_file=None, specific_outfile=None):
         name = project.name
         for tag in project.tags:
             url = project.tag_location(tag)
+            if url.startswith(BASE_ON_SERVER):
+                url = url.replace(BASE_ON_SERVER, BASE)
             logger.info("Found tag %s for %s: %s",
                         tag, name, url)
             update_latest(latest, tag, name, url)
